from __future__ import absolute_import

from optparse import OptionParser

import koji
from koji.plugin import export_cli
from koji_cli.lib import _, activate_session, watch_tasks
from koji_cli.commands import anon_handle_wait_repo

@export_cli
def handle_add_sidetag(options, session, args):
    "Create sidetag"
    usage = _("usage: %prog add-sidetag [options] <basetag>")
    usage += _("\n(Specify the --help global option for a list of other help options)")
    parser = OptionParser(usage=usage)
    parser.add_option("-q", "--quiet", action="store_true",
                      help=_("Do not print tag name"), default=options.quiet)
    parser.add_option("-w", "--wait", action="store_true",
                      help=_("Wait until repo is ready."))
    (opts, args) = parser.parse_args(args)

    if len(args) != 1:
        parser.error(_("Specify basetag"))
    basetag = args[0]

    activate_session(session, options)

    try:
        tag = session.createSideTag(basetag)
    except koji.ActionNotAllowed:
        parser.error(_("Policy violation"))

    if not opts.quiet:
        print(tag['name'])

    if opts.wait:
        args = ["--target", tag["name"]]
        if opts.quiet:
            args.append('--quiet')
        anon_handle_wait_repo(options, session, args)

@export_cli
def handle_remove_sidetag(options, session, args):
    "Remove sidetag"
    usage = _("usage: %prog remove-sidetag [options] <sidetag>")
    usage += _("\n(Specify the --help global option for a list of other help options)")
    parser = OptionParser(usage=usage)
    (opts, args) = parser.parse_args(args)

    if not args:
        parser.error(_("Specify one or more sidetags"))

    activate_session(session, options)

    session.multicall = True
    for sidetag in args:
        session.removeSideTag(sidetag)
    session.multiCall(strict=True)

@export_cli
def handle_list_sidetags(options, session, args):
    "List sidetags"
    usage = _("usage: %prog remove-sidetag [options]")
    usage += _("\n(Specify the --help global option for a list of other help options)")
    parser = OptionParser(usage=usage)
    parser.add_option("--basetag", action="store", help=_("Filter on basetag"))
    parser.add_option("--user", action="store", help=_("Filter on user"))
    parser.add_option("--mine", action="store_true", help=_("Filter on user"))

    (opts, args) = parser.parse_args(args)

    if args:
        parser.error(_("This command takes no arguments."))

    if opts.mine and opts.user:
        parser.error(_("Specify only one from --user --mine"))

    if opts.mine:
        activate_session(session, options)
        user = session.getLoggedInUser()['name']
    else:
        user = opts.user

    for tag in session.listSideTags(basetag=opts.basetag, user=user):
        print(tag['name'])
